@@ -33,11 +33,23 @@ set_envvar <- function(envs, action = "replace") {
 #' Temporarily change system environment variables.
 #'
 #' @template with
-#' @param new \code{[named character]}\cr New environment variables
-#' @param action should new values \code{"replace"}, \code{"prefix"} or
-#'   \code{"suffix"} existing variables with the same name.
-#' @details if \code{NA} is used those environment variables will be unset.
+#' @param new `[named character]`\cr New environment variables
+#' @param action should new values `"replace"`, `"prefix"` or
+#'   `"suffix"` existing variables with the same name.
+#' @inheritParams with_collate
+#' @details if `NA` is used those environment variables will be unset.
 #' If there are any duplicated variable names only the last one is used.
-#' @seealso \code{\link{Sys.setenv}}
+#' @seealso [Sys.setenv()]
+#' @examples
+#' with_envvar(new = c("GITHUB_PAT" = "abcdef"), Sys.getenv("GITHUB_PAT"))
+#'
+#' # with_envvar unsets variables after usage
+#' Sys.getenv("TEMP_SECRET")
+#' with_envvar(new = c("TEMP_SECRET" = "secret"), Sys.getenv("TEMP_SECRET"))
+#' Sys.getenv("TEMP_SECRET")
 #' @export
 with_envvar <- with_(set_envvar)
+
+#' @rdname with_envvar
+#' @export
+local_envvar <- local_(set_envvar)
