@@ -1,6 +1,6 @@
 #' @rdname with_
 #' @export
-local_ <- function(set, reset = set, envir = parent.frame()) {
+local_ <- function(set, reset = set, envir = parent.frame(), new = TRUE) {
 
   fmls <- formals(set)
 
@@ -8,15 +8,19 @@ local_ <- function(set, reset = set, envir = parent.frame()) {
     # called pass all extra formals on
     called_fmls <- stats::setNames(lapply(names(fmls), as.symbol), names(fmls))
 
-    # rename first formal to new
-    called_fmls[[1]] <- as.symbol("new")
+    if (new) {
+      # rename first formal to new
+      called_fmls[[1]] <- as.symbol("new")
 
-    fun_args <- c(alist(new =, code =), fmls[-1L])
+      fun_args <- c(alist(new =), fmls[-1L])
+    } else {
+      fun_args <- fmls
+    }
   } else {
-    # no formals -- only have code
+    # no formals
     called_fmls <- NULL
 
-    fun_args <- alist(code =)
+    fun_args <- alist()
   }
 
   set_call <- as.call(c(substitute(set), called_fmls))
@@ -24,7 +28,7 @@ local_ <- function(set, reset = set, envir = parent.frame()) {
   fun <- eval(bquote(function(args) {
     old <- .(set_call)
     defer(.(reset)(old), envir = .local_envir)
-    old
+    invisible(old)
   }, as.environment(list(set_call = set_call,
                          reset = if (missing(reset)) substitute(set) else substitute(reset)))))
 
